@@ -1498,9 +1498,12 @@ done:
 }
 
 /**
- * @brief Change to the temp dir for storing CDIFFs for incremental database update.
+ * @brief Create a temp dir for storing CDIFFs for incremental database update.
  *
- * Will create the temp dir if it does not already exist.
+ * Will create the temp dir if it does not already exist and populate it with the
+ * unpacked CVD. Then it will chdir to that directory.
+ *
+ * But if that directory already exists, it will simply chdir to it.
  *
  * @param database      The database we're updating.
  * @param[out] tmpdir   The name of the temp dir to use.
@@ -1524,6 +1527,7 @@ static fc_error_t mkdir_and_chdir_for_cdiff_tmp(const char *database, const char
          * yet exist.
          */
         int ret;
+        bool is_cld = false;
 
         /*
          * 1) Double-check that we have a CVD or CLD. Without either one, incremental update won't work.
@@ -1545,6 +1549,8 @@ static fc_error_t mkdir_and_chdir_for_cdiff_tmp(const char *database, const char
                 logg(LOGG_ERROR, "mkdir_and_chdir_for_cdiff_tmp: Can't find (or access) local CVD or CLD for %s database\n", database);
                 goto done;
             }
+
+            is_cld = true;
         }
 
         /*
@@ -1555,7 +1561,10 @@ static fc_error_t mkdir_and_chdir_for_cdiff_tmp(const char *database, const char
             goto done;
         }
 
-        if (-1 == cli_cvdunpack(cvdfile, tmpdir)) {
+        /*
+         * 3) Unpack the existing CVD/CLD database to this directory.
+         */
+        if (CL_SUCCESS != cl_cvdunpack(cvdfile, tmpdir, is_cld == true)) {
             logg(LOGG_ERROR, "mkdir_and_chdir_for_cdiff_tmp: Can't unpack %s into %s\n", cvdfile, tmpdir);
             cli_rmdirs(tmpdir);
             goto done;
@@ -1958,8 +1967,8 @@ static fc_error_t query_remote_database_version(
                     recordTime = atoi(recordTimeStr);
                     free(recordTimeStr);
                     time(&currentTime);
-                    if ((int)currentTime - recordTime > 10800) {
-                        logg(LOGG_WARNING, "DNS record is older than 3 hours.\n");
+                    if ((int)currentTime - recordTime > DNS_WARNING_THRESHOLD_SECONDS) {
+                        logg(LOGG_WARNING, "DNS record is older than %d hours.\n", DNS_WARNING_THRESHOLD_HOURS);
                     } else if (NULL != (verStrDnsExtra = cli_strtok(extradnsreply, 0, ":"))) {
                         if (!cli_isnumber(verStrDnsExtra)) {
                             logg(LOGG_WARNING, "Broken database version in TXT record for %s\n", cvdfile);
@@ -2114,7 +2123,7 @@ static fc_error_t check_for_new_database_version(
         &remotever,
         &remotename);
     switch (ret) {
-        case FC_SUCCESS: {
+        case FC_SUCCESS:
             if (0 == localver) {
                 logg(LOGG_INFO, "%s database available for download (remote version: %d)\n",
                      database, remotever);
@@ -2125,8 +2134,8 @@ static fc_error_t check_for_new_database_version(
                 break;
             }
             /* fall-through */
-        }
-        case FC_UPTODATE: {
+
+        case FC_UPTODATE:
             if (NULL == local_database) {
                 logg(LOGG_ERROR, "check_for_new_database_version: server claims we're up-to-date, but we don't have a local database!\n");
                 status = FC_EFAILEDGET;
@@ -2143,18 +2152,17 @@ static fc_error_t check_for_new_database_version(
                We know it will be the same as the local version though. */
             remotever = localver;
             break;
-        }
-        case FC_EFORBIDDEN: {
+
+        case FC_EFORBIDDEN:
             /* We tried to look up the version using HTTP and were actively blocked. */
             logg(LOGG_ERROR, "check_for_new_database_version: Blocked from using server %s.\n", server);
             status = FC_EFORBIDDEN;
             goto done;
-        }
-        default: {
+
+        default:
             logg(LOGG_ERROR, "check_for_new_database_version: Failed to find %s database using server %s.\n", database, server);
             status = FC_EFAILEDGET;
             goto done;
-        }
     }
 
     *remoteVersion = remotever;
